@@ -77,7 +77,12 @@ class Pipelines(BitbucketCloudBase):
             params["sort"] = sort
         if q is not None:
             params["q"] = q
-        for pipeline in self._get_paged(None, trailing=True, params=params):
+        for pipeline in self._get_paged(
+            None,
+            trailing=True,
+            paging_workaround=True,
+            params=params,
+        ):
             yield self.__get_object(pipeline)
 
         return
@@ -104,32 +109,32 @@ class Pipeline(BitbucketCloudBase):
 
     @property
     def uuid(self):
-        """ The pipeline uuid """
+        """The pipeline uuid"""
         return self.get_data("uuid")
 
     @property
     def build_number(self):
-        """ The pipeline build number """
+        """The pipeline build number"""
         return self.get_data("build_number")
 
     @property
     def build_seconds_used(self):
-        """ The pipeline duration in seconds """
+        """The pipeline duration in seconds"""
         return self.get_data("build_seconds_used")
 
     @property
     def created_on(self):
-        """ The pipeline creation time """
+        """The pipeline creation time"""
         return self.get_time("created_on")
 
     @property
     def completed_on(self):
-        """ The pipeline completion time """
+        """The pipeline completion time"""
         return self.get_time("completed_on")
 
     @property
     def pullrequest(self):
-        """ Returns a PullRequest object if the pipeline was triggered by a pull request, else None """
+        """Returns a PullRequest object if the pipeline was triggered by a pull request, else None"""
         target = self.get_data("target")
         if target["type"] == "pipeline_pullrequest_target":
             return PullRequest(
@@ -176,42 +181,42 @@ class Step(BitbucketCloudBase):
 
     @property
     def uuid(self):
-        """ The step uuid """
+        """The step uuid"""
         return self.get_data("uuid")
 
     @property
     def run_number(self):
-        """ The run number """
+        """The run number"""
         return self.get_data("run_number")
 
     @property
     def started_on(self):
-        """ The step start time """
+        """The step start time"""
         return self.get_time("started_on")
 
     @property
     def completed_on(self):
-        """ The step end time """
+        """The step end time"""
         return self.get_time("completed_on")
 
     @property
     def duration_in_seconds(self):
-        """ The step duration in seconds """
+        """The step duration in seconds"""
         return self.get_data("duration_in_seconds")
 
     @property
     def state(self):
-        """ The step state """
+        """The step state"""
         return self.get_data("state")
 
     @property
     def setup_commands(self):
-        """ The step setup commands """
+        """The step setup commands"""
         return self.get_data("setup_commands")
 
     @property
     def script_commands(self):
-        """ The step script commands """
+        """The step script commands"""
         return self.get_data("script_commands")
 
     def log(self, start=None, end=None):
